"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var GeoJsonDataParser_1 = require("./GeoJsonDataParser");
it('GeoJsonDataParser is defined', function () {
    expect(GeoJsonDataParser_1.default).toBeDefined();
});
describe('GeoJsonDataParser implements DataParser', function () {
    it('readData is defined', function () {
        var gjParser = new GeoJsonDataParser_1.default();
        expect(gjParser.readData).toBeDefined();
    });
});
describe('readData implementation', function () {
    var geojson = {
        type: 'FeatureCollection',
        features: [
            {
                id: 1,
                type: 'Feature',
                geometry: {
                    type: 'Point',
                    coordinates: [1, 1]
                },
                properties: {
                    propString: 'A feature with ID 1',
                    propNumber: 10,
                    propBoolean: true,
                    propArray: ['1111', 'Berga', 'foo'],
                    anotherPropNumber: 400.5
                }
            },
            {
                id: 2,
                type: 'Feature',
                geometry: {
                    type: 'Point',
                    coordinates: [2, 2]
                },
                properties: {
                    propString: 'A feature with ID 2',
                    propNumber: 20,
                    propBoolean: true,
                    propArray: ['2222', 'hello', 'bar'],
                    anotherPropNumber: 200.5
                }
            },
            {
                id: 3,
                type: 'Feature',
                geometry: {
                    type: 'Point',
                    coordinates: [3, 3]
                },
                properties: {
                    propString: 'A feature with ID 3',
                    propNumber: 30,
                    propBoolean: true,
                    propArray: ['3333', 'another', '...'],
                    anotherPropNumber: 300.5
                }
            },
            {
                id: 4,
                type: 'Feature',
                geometry: {
                    type: 'Point',
                    coordinates: [4, 4]
                },
                properties: {
                    propString: 'A feature with ID 4',
                    propNumber: 40,
                    propBoolean: true,
                    propArray: ['4444', 'more', 'and more'],
                    anotherPropNumber: 100.5
                }
            }
        ]
    };
    it('works as expected and returns the correct data in a promise object', function () {
        var gjParser = new GeoJsonDataParser_1.default();
        var promise = gjParser.readData(geojson);
        promise.then(function (output) {
            expect(output).toBeDefined();
            expect(output.exampleFeatures.features.length).toBe(4);
            var expectedSchema = {
                'type': 'object',
                'properties': {
                    'propString': {
                        'type': 'string'
                    },
                    'propNumber': {
                        'type': 'number',
                        'minimum': 10,
                        'maximum': 40
                    },
                    'propBoolean': {
                        'type': 'boolean'
                    },
                    'propArray': {
                        'type': 'array'
                    },
                    'anotherPropNumber': {
                        'type': 'number',
                        'minimum': 100.5,
                        'maximum': 400.5
                    },
                }
            };
            expect(output.schema).toEqual(expectedSchema);
        });
    });
    it('exits when an invalid geojson is given as input', function () {
        var invalidGeojson = {
            type: 'FeatureCollection',
            foo: 'bar',
            kalle: 'Berga'
        };
        var gjParser = new GeoJsonDataParser_1.default();
        var output;
        try {
            output = gjParser.readData(invalidGeojson);
        }
        catch (error) {
            expect(output).toBeUndefined();
        }
    });
    it('exits when an invalid data is given as input', function () {
        var invalidData = '<?xml version="1.0" encoding="UTF-8"?><foo>123</foo>';
        var gjParser = new GeoJsonDataParser_1.default();
        var output;
        try {
            output = gjParser.readData(invalidData);
        }
        catch (error) {
            expect(output).toBeUndefined();
        }
    });
});
//# sourceMappingURL=GeoJsonDataParser.spec.js.map